export interface IVolumeContext {
  /**
   * Your Application Id as provided in your Merchant Portal. (For BETA merchants please contact us directly for your ID.)
   */
  applicationId: string;
  /**
   * Volume Environment to target
   * Accepted values: 'live'|'sandbox'| String
   * Use 'live' or 'sandbox' for the respective api URLs
   *
   * DEFAULT = 'live'
   *
   * Any other String will be used as the API Base URL
   * ie: http://betmate-dev-getvolume.eu-central-1.elasticbeanstalk.com/api/
   */
  volumeEnvironment?: VolumeEnvironment;
  /**
   * Function to subscribe to component events
   */
  onEvent?: (event: VolumeEvent) => void;
  /**
   * Enabling this flag will extend the device installed banks with sandbox bank selections that will open in the device web browser.
   *
   * Currently configured for this are:
   *
   * modelo-sandbox, natwest-sandbox
   *
   * DEFAULT = true
   */
  showSandboxBanks?: boolean;
  /**
   * Enable experimental features
   */
  featureFlags?: FeatureFlags;
}
export interface UseVolume {
  applicationId: string;
  volumeEnvironment: VolumeEnvironment;
  onEvent: (event: VolumeEvent) => void;
  showSandboxBanks: boolean;
  featureFlags: FeatureFlags;
}
export type VolumeEnvironment = "live" | "sandbox" | (string & {});

/**
 * Passed as the only parameter to the `onEvent` function given to the `VolumeProvider`
 */
export interface VolumeEvent {
  /**
   * Enum of unique event types
   */
  type: VolumeEventType;
  /**
   * Unix timestamp
   */
  time: number;
  /**
   * Event specific meta
   */
  meta?: {};
}

/**
 * Unique Enum values for the `type` property of VolumeEvents
 */
export enum VolumeEventType {
  /**
   * Called when Volume button is clicked initiating the create payment request to the Volume API
   */
  PaymentInitiated = "PAYMENT_INITIATED",
  /**
   * Called when AUTHORIZE_SINGLE_DOMESTIC_PAYMENT is returned by the volume api, this occurs when a single domestic payment is successfully authorized
   */
  PaymentAuthorizedSDP = "PAYMENT_AUTHORIZED_SDP",
  /**
   * Called when payment response was not a successful authorization
   */
  PaymentError = "PAYMENT_ERROR",
  /**
   * Something went wrong!
   */
  GenericError = "GENERIC_ERROR",
  /**
   * When the first device payment is made no shopperId exists on the device local storage,
   * this event is called when the shopperId is set from the value returned from the API in the first successful payment request
   */
  SetShoppedId = "SET_SHOPPER_ID",
  /**
   * If the device used for the request is not supported.
   */
  SupportedDevice = "SUPPORTED_DEVICE",
}

/**
 * Object of keys with boolean values to determine feature flag status
 */
export interface FeatureFlags {}

export interface Institution {
  id: string;
  name: string;
  fullName: string;
  media: Media[];
  environmentType: "LIVE" | "SANDBOX";
  credentialsType: string;
  features: string[];
  countries: Country[];
}

interface Country {
  displayName: string;
  countryCode2: string;
}

interface Media {
  type: "logo" | "icon";
  source: string;
}

export interface PaymentRequest {
  amount: number;
  currency: string;
  reference: string;
}
